/*
 * Project: MoleCuilder
 * Description: creates and alters molecular systems
 * Copyright (C)  2010 University of Bonn. All rights reserved.
 * Please see the LICENSE file or "Copyright notice" in builder.cpp for details.
 */

/*
 * BondFileAction.cpp
 *
 *  Created on: May 10, 2010
 *      Author: heber
 */

// include config.h
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "CodePatterns/MemDebug.hpp"

#include "Graph/BondGraph.hpp"
#include "CodePatterns/Log.hpp"
#include "molecule.hpp"
#include "CodePatterns/Verbose.hpp"
#include "World.hpp"

#include <iostream>
#include <fstream>
#include <string>

#include "Actions/MoleculeAction/BondFileAction.hpp"

using namespace MoleCuilder;

// and construct the stuff
#include "BondFileAction.def"
#include "Action_impl_pre.hpp"
/** =========== define the function ====================== */
Action::state_ptr MoleculeBondFileAction::performCall() {
  molecule *mol = NULL;

  // obtain information
  getParametersfromValueStorage();

  if(World::getInstance().countSelectedMolecules() == 1) {
    mol = World::getInstance().beginMoleculeSelection()->second;
    LOG(0, "STATUS: Parsing bonds from " << params.bondfile
        << ", skipping " << params.skiplines << "lines"
        << ", adding " << params.id_offset << " to each id.");
    ifstream input(params.bondfile.string().c_str());
    World::AtomComposite Set = mol->getAtomSet();
    World::getInstance().getBondGraph()->CreateAdjacencyListFromDbondFile(Set, &input, params.skiplines, params.id_offset);
    input.close();
    mol->getBondCount();
    return Action::success;
  } else
    return Action::failure;
}

Action::state_ptr MoleculeBondFileAction::performUndo(Action::state_ptr _state) {
//  MoleculeBondFileState *state = assert_cast<MoleculeBondFileState*>(_state.get());

//  string newName = state->mol->getName();
//  state->mol->setName(state->lastName);

  return Action::failure;
}

Action::state_ptr MoleculeBondFileAction::performRedo(Action::state_ptr _state){
  return Action::failure;
}

bool MoleculeBondFileAction::canUndo() {
  return true;
}

bool MoleculeBondFileAction::shouldUndo() {
  return true;
}
/** =========== end of function ====================== */
